module.exports = function(grunt) {

	var servicesPath = 'src/services/**/*.js';
	var controllersPath = 'src/controllers/**/*.js';
	var directivesPath = 'src/directives/**/*.js';
	var configPath = 'src/config/**/*.js';
	var assetsPath = ['src/**/*.js'];
	var exceptPath = ['!src/utilities/**/'];
	var examplePath = 'example/mobile/js/**/*.js';

	grunt.initConfig({
		jshint: {
			all: ['GruntFile.js', assetsPath, exceptPath]
		},
		watch: {
			pivotal: {
				files: [assetsPath],
				tasks: ['jshint', 'concat']
			}
		},
		bump: {
			options: {
				files: ['bower.json', 'package.json'],
				pushTo: 'origin',
				commitFiles: ["-a"],
				push: true
			}
		},
		concat: {
			zh: {
				options: {
					process: function(src, filepath) {
						return '\n' + '// FILE: ' + filepath + '\n' + src;
					}
				},
				src: [configPath, servicesPath, controllersPath, directivesPath, exceptPath],
				dest: 'dist/zh-scheduler.js'
			},
			example: {
				options: {
					process: function(src, filepath) {
						return '\n' + '// FILE: ' + filepath + '\n' + src;
					}
				},
				src: examplePath,
				dest: 'example/mobile/dist/zh-scheduler-example.js'
			}
		},
		uglify: {
			options: {
				mangle: false
			},
			target: {
				files: {
					'dist/zh-scheduler.min.js': ['dist/zh-scheduler.js']
				}
			}
		},
		copy: {
			main: {
				expand: true,
				cwd: 'src/',
				src: 'templates/**/*',
				dest: 'dist/'
			}
		},
		zhIdGenerator: {
			options: {
				jsonPath: [
					"example/mobile/json",
					{
						path: "example/mobile/json",
						projectName: "scheduler"
					}
				],
				replaceIds: false
			}
		},
		buildEnvironment: {
			deploy: {
				configFile: 'config/deploy.json'
			},
			development: {
				configFile: 'config/development.json'
			},
			srcFolders: ['example/mobile/', 'tests/functional/']
		},
	});

	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-copy');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-bump');
	grunt.loadNpmTasks('grunt-zh-environment-builder');
	grunt.loadNpmTasks('grunt-zh-id-generator');

	grunt.registerTask('default', ['jshint', 'concat']);
	// Task to execute before do a merge request and when deploy the product.
	grunt.registerTask('deploy', ['jshint', 'concat', 'uglify', 'copy', 'buildEnvironment:deploy']);
	// Task to execute before commit
	grunt.registerTask('commit', ['jshint', 'concat', 'uglify', 'copy']);
	// Task to execute when start tp dp a task
	grunt.registerTask('build-dev', ['jshint', 'concat', 'uglify', 'copy', 'buildEnvironment:development']);
};